pub fn analyze_pair(
path: &Path,
left: &[u8],
right: &[u8],
) -> (AssetClass, SemanticDelta)Expand description
Analyze two file versions and return asset class + semantic delta.
pub fn analyze_pair(
path: &Path,
left: &[u8],
right: &[u8],
) -> (AssetClass, SemanticDelta)Analyze two file versions and return asset class + semantic delta.